# chATLAS Scrape

This package provides utilities for scraping and processing data for chATLAS.

The following sources are currently supported:
- **GitLab**: Scrapes markdown files from CERN GitLab repositories.

## Installation

You can install the package using `uv`:

```sh
uv sync
```


## Tests

To run the tests, use:

```sh
uv run pytest
```
